import { Component, ChangeDetectionStrategy, NgModule, NO_ERRORS_SCHEMA } from '@angular/core';
import { CommonModule } from '@angular/common';
import { FieldType, FormlyModule } from '@ngx-formly/core';
import { FormlySelectModule } from '@ngx-formly/core/select';
import { ReactiveFormsModule } from '@angular/forms';
import { NativeScriptFormsModule } from '@nativescript/angular';
import { FormlyNsFormFieldModule } from '@ngx-formly/nativescript/form-field';
import { action } from '@nativescript/core/ui/dialogs';

class FormlyFieldSelect extends FieldType {
    tap(options) {
        action({ title: this.to.label, actions: options.map((o) => o.label) }).then((selectedAction) => this.formControl.patchValue(options.find((o) => o.label === selectedAction).value));
    }
    selectedItem(options) {
        if (this.formControl.value) {
            return options.find((o) => o.value === this.formControl.value).label;
        }
        return this.to.placeholder;
    }
}
FormlyFieldSelect.decorators = [
    { type: Component, args: [{
                selector: 'formly-field-ns-select',
                template: `
    <ng-container *ngIf="to.options | formlySelectOptions: field | async as options">
      <Button (tap)="tap(options)" [text]="selectedItem(options)"></Button>
    </ng-container>
  `,
                changeDetection: ChangeDetectionStrategy.OnPush
            },] }
];

class FormlyNsSelectFieldModule {
}
FormlyNsSelectFieldModule.decorators = [
    { type: NgModule, args: [{
                declarations: [FormlyFieldSelect],
                imports: [
                    CommonModule,
                    ReactiveFormsModule,
                    NativeScriptFormsModule,
                    FormlyNsFormFieldModule,
                    FormlySelectModule,
                    FormlyModule.forChild({
                        types: [
                            {
                                name: 'select',
                                component: FormlyFieldSelect,
                                wrappers: ['form-field'],
                            },
                            { name: 'enum', extends: 'select' },
                        ],
                    }),
                ],
                schemas: [NO_ERRORS_SCHEMA],
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { FormlyNsSelectFieldModule, FormlyFieldSelect as ɵa };
//# sourceMappingURL=ngx-formly-nativescript-select.js.map
